<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 * @return array An array of default values
 */

function moun10_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$moun10_pro_default_options = array(
		// Color Options
		'header_title_color'			    => '#fff',
		'header_tagline_color'			    => '#fff',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#fe463a',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'dark-version',
		'home_layout'						=> 'default-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
		
		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,
		'menu_transparent'					=> (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,
		'read_more_text'           		    => esc_html__( 'Read More', 'moun10-pro' ),

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'moun10-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'moun10-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'moun10-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'sortable' 						    => 'slider,trip_search,about,popular_destination,featured_product,features,service,package,cta,featured_package,recent_product,counter,must_read,team,offer,recommended_package,destination,testimonial,course,blog,subscription',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'moun10-pro' ),
		'hide_date' 					    => (bool) false,
		'hide_category'					    => (bool) false,
		'blog_layout_design'				=> '',
		'blog_column'						=> 'col-2',


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,

		/* Front Page */

		//top bar
		'topbar_section_enable'				=> true,
		'social_menu_enable'				=> true,
		'topbar_field_1'					=> '(123) 456 4521',
		'topbar_field_2'					=> 'info@mountain.com',

		// Slider
		'slider_section_enable'				=> (bool) true,
		'trip_search_section_enable'		=> (bool) false,
		'slider_content_type'				=> 'post',
		'slider_section_sub_title'			=> esc_html__('mesmerizing View','moun10-pro'),
		'slider_count'						=> 4,
		'slider_autoplay_enable'			=> (bool) false,
		'slider_btn_txt'                    => esc_html__('START TOUR','moun10-pro'),
		'slider_btn_alt_txt'                => esc_html__('Explore more','moun10-pro'),
		'slider_btn_alt_url'				=> '#',


		
		//about 
		'about_section_enable'			    => (bool) true,
		'about_content_type'			    =>'post',
		'about_custom_title'				=> esc_html__('Himalayan lifestyle','moun10-pro'),
		'about_section_title'				=> esc_html__('About Us','moun10-pro'),
		'about_custom_content'				=> esc_html__('You don’t climb mountains without a team, you don’t climb mountains without being fit, you don’t climb mountains without being prepared and you don’t climb mountains without balancing the risks and rewards. And you never climb a mountain on accident-it has to be intentional.','moun10-pro'),

		
		//service
		'service_section_enable'		    => (bool) true,
		'service_section_sub_title'			=> esc_html__( 'MOUNTAIN HISTORY', 'moun10-pro' ),
		'service_content_type'			    =>'post',
		'service_posts_count'			    => 2,
		'service_section_btn_txt'           => esc_html__('Show Me More', 'moun10-pro'),
		'service_post_btn_txt'              => esc_html__('Read More', 'moun10-pro'),
		'service_show_more'			        => 'ajax',
		'service_section_title'			    => esc_html__( 'Discover histroy of Plant and animal around mountain range', 'moun10-pro' ),



        //destination
		'destination_autoplay_enable'       => (bool) true,
		'destination_section_sub_title'     => esc_html__('Explore mountain','moun10-pro'),
		'destination_section_title'         => esc_html__('Top things to do in Himalaya','moun10-pro'),
		'destination_section_enable'	    => (bool) true,
		'destination_content_type'		    => 'post',
		'destination_posts_count'		    => 4,
		'destination_section_btn_txt'       => esc_html__('Show more', 'moun10-pro'),
		'destination_section_description'	=> esc_html__('You don’t climb mountains without a team, you don’t climb mountains without being fit, you don’t climb mountains without being prepared and you don’t climb mountains without balancing the risks and rewards. And you never climb a mountain on accident-it has to be intentional.','moun10-pro'),
		

		//testimonial
        'testimonial_section_enable'        => (bool) true,
		'testimonial_section_sub_title'     => esc_html__('Testimonial','moun10-pro'),
		'testimonial_section_title'	        => esc_html__('Why we love mountain','moun10-pro'),
		'testimonial_content_type'          =>'post',
		'testimonial_posts_count'           =>4,

		// blog
		'blog_section_enable'			    => (bool) true,
		'blog_section_sub_title'            => esc_html__('From the blog','moun10-pro'),
		'blog_right_sidebar_title'          => esc_html__('Most Popular','moun10-pro'),
		'blog_content_type'				    => 'recent',
		'blog_count'					    => 6,
		'blog_title'					    => esc_html__( 'Amazing mountain articles', 'moun10-pro' ),
		'blog_btn_title'				    => esc_html__( 'Show All', 'moun10-pro' ),

        //subscription
        'subscription_section_enable'       => (bool) true,
        'subscription_section_sub_title'    => esc_html__('Subscription','moun10-pro'),
        'subscription_section_bg_image'   	=> get_template_directory_uri().'/assets/uploads/subscribe-01.jpg',
        'subscription_section_title'        => esc_html__('The best of Mountain to your inbox','moun10-pro'),
        'subscription_section_description'  => esc_html__('By signing up for this email, you are agreeing to receive news, offers, and information from Mounten.com, LLC and our partners. Easy unsubscribe links are provided in every email.','moun10-pro'),
        'subscription_section_placeholder'  => esc_html__('Enter your Email address','moun10-pro'),
		'subscription_section_btn_txt'      => esc_html__('Subscribe now','moun10-pro'),
		
		// team
		'team_section_enable'			=> true,
		'team_content_type'				=> 'category',
		'team_count'					=> 4,
		'team_column'					=> 'col-4',
		'team_title'					=> esc_html__( 'Meet Our Team', 'moun10-pro' ),
		'team_sub_title'				=> esc_html__( 'Our Team', 'moun10-pro' ),
		'team_btn_title'				=> esc_html__( 'View All Team', 'moun10-pro' ),

		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,

		// Features
		'features_section_enable'		=> true,
		'features_content_type'			=> 'category',
		'features_title'				=> esc_html__( 'GET THE WORLD CLASS & VERIFIED COURSE', 'moun10-pro' ),
		'features_description'			=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'moun10-pro' ),
		'features_count'				=> 3,
		'features_column'				=> 'col-3',

		// Must Read
		'must_read_title'				=> esc_html__( 'Must Read Section', 'moun10-pro' ),
		'must_read_sub_title'	     	=> esc_html__( 'Must Read', 'moun10-pro' ),
		'must_read_section_enable'		=> true,
		'must_read_content_type'		=> 'category',
		'must_read_count'				=> 3,
		'must_read_btn_title'			=> esc_html__( 'Read More', 'moun10-pro' ),

		// popular destination
		'popular_destination_section_enable'		=> true,
		'popular_destination_content_type'			=> 'category',
		'popular_destination_column_type'			=> 3,
		'popular_destination_count'					=> 3,
		'popular_destination_title'					=> esc_html__( 'Popular Destinations', 'moun10-pro' ),
		'popular_destination_sub_title'				=> esc_html__('DESTINATIONS','moun10-pro'),
		'popular_destination_btn_label'				=> esc_html__( 'Let’s Travel Now', 'moun10-pro' ),
		'popular_destination_read_more_btn_label'	=> esc_html__( 'More Details', 'moun10-pro' ),
		'popular_destination_btn_url'				=> '#',

		// package
		'package_section_enable'		=> true,
		'package_content_type'			=> 'category',
		'package_count'					=> 2,
		'package_title'					=> esc_html__( 'Recommended Packages', 'moun10-pro' ),
		'package_sub_title'				=> esc_html__('Tour Types', 'moun10-pro'),
		'package_btn_label'				=> esc_html__( 'Book This Package', 'moun10-pro' ),

		// offer
		'offer_section_enable'			=> true,
		'offer_content_type'			=> 'category',
		'offer_count'					=> 4,
		'offer_title'					=> esc_html__( 'Special Offers', 'moun10-pro' ),
		'offer_sub_title'				=> esc_html__('OFFERS', 'moun10-pro'),
		'offer_btn_title'				=> esc_html__( 'View All Offer', 'moun10-pro' ),

		
		// recommended_package
		'recommended_package_section_enable'		=> true,
		'recommended_package_content_type'			=> 'category',
		'recommended_package_count'					=> 3,
		'recommended_package_title'					=> esc_html__( 'Recommended Packages', 'moun10-pro' ),
		'recommended_package_btn_label'				=> esc_html__( 'Recommended Packages', 'moun10-pro' ),
		'recommended_package_sub_title'				=> esc_html__('Tour Types', 'moun10-pro'),
		'recommended_package_btn_title'				=> esc_html__( 'Book This Package', 'moun10-pro' ),
		'recommended_package_read_more_btn_label'	=> esc_html__( 'Book Now', 'moun10-pro' ),

		
		// featured_package
		'featured_package_section_enable'			=> true,
		'featured_package_content_type'				=> 'category',
		'featured_package_column_type'				=> 3,
		'featured_package_count'					=> 3,
		'featured_package_title'					=> esc_html__( 'Featured Packages', 'moun10-pro' ),
		'featured_package_sub_title'				=> esc_html__('Featured', 'moun10-pro'),
		'featured_package_btn_label'				=> esc_html__( 'View All Packages', 'moun10-pro' ),

		//cta
		'cta_section_enable' 	=> true,
		'cta_sub_title'			=> 	esc_html__('STARTING FROM', 'moun10-pro'),
		'cta_content_type'		=> 'post',
		'cta_read_more'			=>	esc_html__('Book Now', 'moun10-pro'),


		//Recent Product
		'recent_product_section_enable'			=> false,
		'recent_product_content_type'			=> 'product-category',
		'recent_product_count'					=> 4,
		'recent_product_subtitle'				=> esc_html__( 'Recent Products', 'moun10-pro' ),
		'recent_product_title'			    	=> esc_html__( 'Shopping Every Day', 'moun10-pro' ),

		//Featured Product
		'featured_product_section_enable'		=> false,
		'featured_product_content_type'			=> 'product-category',
		'featured_product_count'				=> 4,
		'featured_product_title'				=> esc_html__( 'Latest Spring Collection', 'moun10-pro' ),
		'featured_product_btn_title'			=> esc_html__( 'Add To Cart', 'moun10-pro' ),
		'featured_product_subtitle'				=> esc_html__( 'Featured Products', 'moun10-pro' ),

		// team
		'course_section_enable'			=> true,
		'course_content_type'			=> 'category',
		'course_count'					=> 3,
		'course_title'					=> esc_html__( 'Courses', 'moun10-pro' ),
		'course_sub_title'				=> esc_html__( 'Check out our latest blog posts, articles, client success stories and essential announcement', 'moun10-pro' ),

	);

	$output = apply_filters( 'moun10_pro_default_theme_options', $moun10_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}