<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'moun10_pro_about_section', array(
	'title'             => esc_html__( 'About us','moun10-pro' ),
	'description'       => esc_html__( 'About us  Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_about_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[about_section_enable]', array(
		'selector'            => '#about-us .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[about_section_enable]',
    ) );
}

// about section title control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[about_section_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
	'default'			=> 	$options['about_section_title'],
	'transport'			=>'postMessage'
) );

$wp_customize->add_control('moun10_pro_theme_options[about_section_title]', array(
    'label'             => esc_html__( 'Section Sub Title', 'moun10-pro' ),
    'section'           => 'moun10_pro_about_section',
    'type'              =>'text',
    'active_callback'	=> 'moun10_pro_is_about_section_enable',
));
$wp_customize->selective_refresh->add_partial(
    'moun10_pro_theme_options[about_section_title]',
    array(
        'selector'            => '#about-us .section-subtitle',
        'render_callback'     => 'moun10_pro_about_section_partial_title',
    )
);

// About content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_about_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'moun10-pro' ),
            'post' 		=> esc_html__( 'Post', 'moun10-pro' ),
            'category' 	=> esc_html__( 'Category', 'moun10-pro' ),
            'custom' 	=> esc_html__( 'Custom', 'moun10-pro' ),
	),
) );

	// about pages drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[about_content_page]', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[about_content_page]', array(
		'label'             => esc_html__( 'Select Page', 'moun10-pro' ),
		'section'           => 'moun10_pro_about_section',
		'choices'			=> moun10_pro_page_choices(),
		'active_callback'	=> 'moun10_pro_is_about_section_content_page_enable',
	) ) );

	// about posts drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[about_content_post]', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[about_content_post]', array(
		'label'             => esc_html__( 'Select Post', 'moun10-pro' ),
		'section'           => 'moun10_pro_about_section',
		'choices'			=> moun10_pro_post_choices(),
		'active_callback'	=> 'moun10_pro_is_about_section_content_post_enable',
	) ) );


// about posts drop down chooser control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[about_category]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_single_category',
) );

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'moun10_pro_theme_options[about_category]', array(
	'label'             => esc_html__( 'Select Categories', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'moun10_pro_about_section',
	'active_callback'	=> 'moun10_pro_is_about_section_content_category_enable',
) ) ); 

// About title setting
$wp_customize->add_setting('moun10_pro_theme_options[about_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_custom_title']
    )
);

$wp_customize->add_control('moun10_pro_theme_options[about_custom_title]',
    array(
        'section'			=> 'moun10_pro_about_section',
        'label'				=> esc_html__( 'Title:', 'moun10-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'moun10_pro_if_about_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('moun10_pro_theme_options[about_custom_title]',
    array(
        'selector'            => '#about-us .section-title',
        'render_callback'     => 'moun10_pro_about_section_partial_custom_title',
    )
);

// About content setting
$wp_customize->add_setting('moun10_pro_theme_options[about_custom_content]',
    array(
        'sanitize_callback' => 'sanitize_textarea_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_custom_content']

    )
);

$wp_customize->add_control('moun10_pro_theme_options[about_custom_content]',
    array(
        'section'			=> 'moun10_pro_about_section',
        'label'				=> esc_html__( 'Content:', 'moun10-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'moun10_pro_if_about_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('moun10_pro_theme_options[about_custom_content]',array(
        'selector'            => '#about-us .section-header span.content',
        'render_callback'     => 'moun10_pro_about_section_partial_custom_content',
    )
);
// About link setting
$wp_customize->add_setting(
    'moun10_pro_theme_options[about_video_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
        'default' 			=> '#',
    )
);

$wp_customize->add_control(
    'moun10_pro_theme_options[about_video_url]',
    array(
        'section'			=> 'moun10_pro_about_section',
        'label'				=> esc_html__( 'Video URL Link:', 'moun10-pro' ),
        'type'				=> 'url',
        'active_callback' 	=> 'moun10_pro_is_about_section_enable'
    )
);
// About image setting
$wp_customize->add_setting(
    'moun10_pro_theme_options[about_thumbnail_img]',
    array(
        'sanitize_callback' => 'moun10_pro_sanitize_image',
    )
);

$wp_customize->add_control(
    new WP_Customize_Image_Control(
        $wp_customize,
        'moun10_pro_theme_options[about_thumbnail_img]',
        array(
            'section'			=> 'moun10_pro_about_section',
            'label'				=> esc_html__( 'Video Thumbnail Image:', 'moun10-pro' ),
            'active_callback' 	=> 'moun10_pro_is_about_section_enable',
        )
    )
);
