<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'moun10_pro_blog_section', array(
    'title'             => esc_html__( 'Blog','moun10-pro' ),
    'description'       => esc_html__( 'Blog Section options.', 'moun10-pro' ),
    'panel'             => 'moun10_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[blog_section_enable]', array(
    'default'           =>  $options['blog_section_enable'],
    'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[blog_section_enable]', array(
    'label'             => esc_html__( 'Blog Section Enable', 'moun10-pro' ),
    'section'           => 'moun10_pro_blog_section',
    'on_off_label'      => moun10_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[blog_section_enable]', array(
		'selector'            => '#blog .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[blog_section_enable]',
    ) );
}

// Blog section sub title control and setting
$wp_customize->add_setting('moun10_pro_theme_options[blog_section_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'transport' => 'postMessage',
    'default'  => $options['blog_section_sub_title'],
));

$wp_customize->add_control('moun10_pro_theme_options[blog_section_sub_title]', array(
    'label' => esc_html__('Section Sub Title', 'moun10-pro'),
    'section' => 'moun10_pro_blog_section',
    'type' => 'text',
    'active_callback' => 'moun10_pro_is_blog_section_enable',
));
$wp_customize->selective_refresh->add_partial(
    'moun10_pro_theme_options[blog_section_sub_title]',
    array(
        'selector' => '#blog .section-subtitle',
        'render_callback' => 'moun10_pro_blog_section_partial_sub_title',
    )
);
// blog title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[blog_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['blog_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[blog_title]', array(
    'label'             => esc_html__( 'Title', 'moun10-pro' ),
    'section'           => 'moun10_pro_blog_section',
    'active_callback'   => 'moun10_pro_is_blog_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[blog_title]', array(
        'selector'            => '#blog .section-header h2',
        'settings'            => 'moun10_pro_theme_options[blog_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'moun10_pro_blog_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[blog_count]', array(
    'default'           => $options['blog_count'],
    'sanitize_callback' => 'moun10_pro_sanitize_number_range',
    'validate_callback' => 'moun10_pro_validate_blog_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[blog_count]', array(
    'label'             => esc_html__( 'Number of Posts', 'moun10-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
    'section'           => 'moun10_pro_blog_section',
    'active_callback'   => 'moun10_pro_is_blog_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 10,
        'style' => 'width: 100px;'
        ),
) );

// Blog content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[blog_content_type]', array(
    'default'           => $options['blog_content_type'],
    'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[blog_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
    'section'           => 'moun10_pro_blog_section',
    'type'              => 'select',
    'active_callback'   => 'moun10_pro_is_blog_section_enable',
    'choices'           => array( 
            'page'      => esc_html__( 'Page', 'moun10-pro' ),
            'post'      => esc_html__( 'Post', 'moun10-pro' ),
            'category'  => esc_html__( 'Category', 'moun10-pro' ),
            'recent'    => esc_html__( 'Recent', 'moun10-pro' ),
    ),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
    // blog pages drop down chooser control and setting
    $wp_customize->add_setting( 'moun10_pro_theme_options[blog_content_page_' . $i . ']', array(
        'sanitize_callback' => 'moun10_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[blog_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Page %d', 'moun10-pro' ), $i ),
        'section'           => 'moun10_pro_blog_section',
        'choices'           => moun10_pro_page_choices(),
        'active_callback'   => 'moun10_pro_is_blog_section_content_page_enable',
    ) ) );

    // blog posts drop down chooser control and setting
    $wp_customize->add_setting( 'moun10_pro_theme_options[blog_content_post_' . $i . ']', array(
        'sanitize_callback' => 'moun10_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[blog_content_post_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Post %d', 'moun10-pro' ), $i ),
        'section'           => 'moun10_pro_blog_section',
        'choices'           => moun10_pro_post_choices(),
        'active_callback'   => 'moun10_pro_is_blog_section_content_post_enable',
    ) ) );

    //blog separator
    $wp_customize->add_setting('moun10_pro_theme_options[blog_separator'. $i .']',array(
        'sanitize_callback'      => 'moun10_pro_sanitize_html',
    ));

    $wp_customize->add_control(new Moun10_Pro_Customize_Horizontal_Line($wp_customize,'moun10_pro_theme_options[blog_separator'. $i .']',array(
        'active_callback'       => 'moun10_pro_is_blog_section_separator_enable',
        'type'                  =>'hr',
        'section'               =>'moun10_pro_blog_section',
    )));
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[blog_content_category]', array(
    'sanitize_callback' => 'moun10_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[blog_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'moun10-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
    'section'           => 'moun10_pro_blog_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'moun10_pro_is_blog_section_content_category_enable'
) ) );

// blog title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[blog_right_sidebar_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['blog_right_sidebar_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[blog_right_sidebar_title]', array(
    'label'             => esc_html__( 'Right Sidebar Title', 'moun10-pro' ),
    'section'           => 'moun10_pro_blog_section',
    'active_callback'   => 'moun10_pro_is_blog_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[blog_right_sidebar_title]', array(
        'selector'            => '#blog div.blog-post-wrapper .blog-widget h2',
        'settings'            => 'moun10_pro_theme_options[blog_right_sidebar_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'moun10_pro_blog_right_sidebar_title_partial',
    ) );
}
// Add dropdown categories setting and control.
$wp_customize->add_setting( 'moun10_pro_theme_options[blog_category_exclude]', array(
    'sanitize_callback' => 'moun10_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Multiple_Chooser( $wp_customize,'moun10_pro_theme_options[blog_category_exclude]', array(
    'label'             => esc_html__( 'Select Excluding Categories', 'moun10-pro' ),
    'section'           => 'moun10_pro_blog_section',
    'type'              => 'dropdown_multiple_chooser',
    'choices'           =>  moun10_pro_category_choices(),
    'active_callback'   => 'moun10_pro_is_blog_section_content_recent_enable'
) ) );

