<?php
/**
 * Featured package Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Featured package section
$wp_customize->add_section( 'moun10_pro_featured_package_section', array(
	'title'             => esc_html__( 'Featured package','moun10-pro' ),
	'description'       => esc_html__( 'Featured package Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',

) );

// Featured package content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_section_enable]', array(
	'default'			=> 	$options['featured_package_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[featured_package_section_enable]', array(
	'label'             => esc_html__( 'Featured package Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_featured_package_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[featured_package_section_enable]', array(
		'selector'            => '#featured-package .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[featured_package_section_enable]',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_sub_title]', array(
	'default'			=> $options['featured_package_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[featured_package_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_featured_package_section',
	'active_callback' 	=> 'moun10_pro_is_featured_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[featured_package_sub_title]', array(
		'selector'            => '#featured-package .section-header p.section-subtitle',
		'settings'            => 'moun10_pro_theme_options[featured_package_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_featured_package_sub_title_partial',
    ) );
}

// popular destination title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_title]', array(
	'default'			=> $options['featured_package_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[featured_package_title]', array(
	'label'           	=> esc_html__( 'Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_featured_package_section',
	'active_callback' 	=> 'moun10_pro_is_featured_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[featured_package_title]', array(
		'selector'            => '#featured-package .section-header h2.section-title',
		'settings'            => 'moun10_pro_theme_options[featured_package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_featured_package_title_partial',
    ) );
}

// Featured package column type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_column_type]', array(
	'default'          	=> $options['featured_package_column_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[featured_package_column_type]', array(
	'label'             => esc_html__( 'Column Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_featured_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_featured_package_section_enable',
	'choices'			=> array(
		3	=> esc_html__( 'Column Three', 'moun10-pro' ),
		4	=> esc_html__( 'Column Four', 'moun10-pro' ),
		5	=> esc_html__( 'Column Five', 'moun10-pro' ),
		),
) );

//Featured package post count number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_count]', array(
	'default'          	=> $options['featured_package_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_featured_package_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[featured_package_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_featured_package_section',
	'active_callback'   => 'moun10_pro_is_featured_package_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Featured package content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_content_type]', array(
	'default'          	=> $options['featured_package_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[featured_package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_featured_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_featured_package_section_enable',
	'choices'			=> moun10_pro_featured_package_content_type(),
) );

// counter hr setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_hr]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_html',
) );

$wp_customize->add_control( new Moun10_Pro_Customize_Horizontal_Line( $wp_customize, 'moun10_pro_theme_options[featured_package_hr]',
	array(
		'section'         => 'moun10_pro_featured_package_section',
		'active_callback' => 'moun10_pro_is_featured_package_section_enable',
		'type'			  => 'hr',
) ) );

for ( $i=1; $i <= $options['featured_package_count']; $i++ ) { 

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'moun10_pro_theme_options[featured_package_content_category_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_single_category',
	) ) ;

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[featured_package_content_category_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Category %d', 'moun10-pro'), $i ),
		'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
		'section'           => 'moun10_pro_featured_package_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'moun10_pro_is_featured_package_section_content_category_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'moun10_pro_theme_options[featured_package_content_trip_types_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[featured_package_content_trip_types_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Trip Types %d', 'moun10-pro'), $i ),
		'section'           => 'moun10_pro_featured_package_section',
		'taxonomy'			=> 'itinerary_types',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'moun10_pro_is_featured_package_section_content_trip_types_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'moun10_pro_theme_options[featured_package_content_activity_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[featured_package_content_activity_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Activities %d', 'moun10-pro'), $i ),
		'section'           => 'moun10_pro_featured_package_section',
		'taxonomy'			=> 'activity',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'moun10_pro_is_featured_package_section_content_activity_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'moun10_pro_theme_options[featured_package_content_destination_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[featured_package_content_destination_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Destinations %d ', 'moun10-pro'), $i ),
		'section'           => 'moun10_pro_featured_package_section',
		'taxonomy'			=> 'travel_locations',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'moun10_pro_is_featured_package_section_content_destination_enable'
	) ) );

	// Featured image enable control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_background_image_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'moun10_pro_theme_options[featured_package_background_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Category Image %d', 'moun10-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'moun10-pro' ), 500, 500 ),
			'section'     		=> 'moun10_pro_featured_package_section',
			'active_callback'	=> 'moun10_pro_is_featured_package_section_content_category_enable',
	) ) );

	// counter hr setting and control
	$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_hr_'. $i .']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_html',
	) );

	$wp_customize->add_control( new Moun10_Pro_Customize_Horizontal_Line( $wp_customize, 'moun10_pro_theme_options[featured_package_hr_'. $i .']',
		array(
			'section'         => 'moun10_pro_featured_package_section',
			'active_callback' => 'moun10_pro_is_featured_package_section_enable',
			'type'			  => 'hr',
	) ) );
	
}
// Popular deatination btn label setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_package_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[featured_package_btn_label]', array(
	'label'           	=> esc_html__( 'Featured package Button Label', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_featured_package_section',
	'active_callback' 	=> 'moun10_pro_is_featured_package_section_enable',
	'type'				=> 'text',
) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[featured_package_btn_label]', array(
		'selector'            => '#featured-package div.read-more a',
		'settings'            => 'moun10_pro_theme_options[featured_package_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_featured_package_btn_label_partial',
    ) );
}

$wp_customize->add_setting( 'moun10_pro_theme_options[featured_package_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[featured_package_btn_url]', array(
	'label'           	=> esc_html__( 'Featured package Button Url', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_featured_package_section',
	'active_callback' 	=> 'moun10_pro_is_featured_package_section_enable',
	'type'				=> 'url',
) );
