<?php
/**
 * Must Read Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Must Read section
$wp_customize->add_section( 'moun10_pro_must_read_section', array(
	'title'             => esc_html__( 'Must Read','moun10-pro' ),
	'description'       => esc_html__( 'Must Read Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',
	) );

// Must Read content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[must_read_section_enable]', array(
	'default'			=> 	$options['must_read_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[must_read_section_enable]', array(
	'label'             => esc_html__( 'Must Read Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_must_read_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
	) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[must_read_section_enable]', array(
		'selector'            => '#must-read .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[must_read_section_enable]',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[must_read_sub_title]', array(
	'default'			=> $options['must_read_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[must_read_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_must_read_section',
	'active_callback' 	=> 'moun10_pro_is_must_read_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[must_read_sub_title]', array(
		'selector'            => '#must-read .business-section-header p.section-subtitle',
		'settings'            => 'moun10_pro_theme_options[must_read_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_must_read_sub_title_partial',
    ) );
}

// must_read title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[must_read_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['must_read_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'moun10_pro_theme_options[must_read_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_must_read_section',
	'active_callback' 	=> 'moun10_pro_is_must_read_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[must_read_title]', array(
		'selector'            => '#must-read .business-section-header h2',
		'settings'            => 'moun10_pro_theme_options[must_read_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_must_read_title_partial',
		) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[must_read_count]', array(
	'default'          	=> $options['must_read_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_must_read_count',
	) );

$wp_customize->add_control( 'moun10_pro_theme_options[must_read_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_must_read_section',
	'active_callback'   => 'moun10_pro_is_must_read_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
	) );

// Must Read content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[must_read_content_type]', array(
	'default'          	=> $options['must_read_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
	) );

$wp_customize->add_control( 'moun10_pro_theme_options[must_read_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_must_read_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_must_read_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'moun10-pro' ),
		'post' 		=> esc_html__( 'Post', 'moun10-pro' ),
		'category' 	=> esc_html__( 'Category', 'moun10-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['must_read_count']; $i++ ) :
	// must_read pages drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[must_read_content_page_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
		) );

$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[must_read_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'moun10-pro' ), $i ),
	'section'           => 'moun10_pro_must_read_section',
	'choices'			=> moun10_pro_page_choices(),
	'active_callback'	=> 'moun10_pro_is_must_read_section_content_page_enable',
	) ) );

	// must_read posts drop down chooser control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[must_read_content_post_' . $i . ']', array(
	'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[must_read_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'moun10-pro' ), $i ),
	'section'           => 'moun10_pro_must_read_section',
	'choices'			=> moun10_pro_post_choices(),
	'active_callback'	=> 'moun10_pro_is_must_read_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[must_read_content_category]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[must_read_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'moun10-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
	'section'           => 'moun10_pro_must_read_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_must_read_section_content_category_enable'
    ) ) );
    

// must_read btn title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[must_read_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['must_read_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[must_read_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_must_read_section',
	'active_callback' 	=> 'moun10_pro_is_must_read_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[must_read_btn_title]', array(
		'selector'            => '#must-read article div.business-read-more a',
		'settings'            => 'moun10_pro_theme_options[must_read_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_must_read_btn_title_partial',
    ) );
}
