<?php
/**
 * Product Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Product section
$wp_customize->add_section( 'moun10_pro_recent_product_section', array(
	'title'             => esc_html__( 'Recent Product','moun10-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',
) );

// Product content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[recent_product_section_enable]', array(
	'default'			=> 	$options['recent_product_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[recent_product_section_enable]', array(
	'label'             => esc_html__( 'Product Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_recent_product_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[recent_product_section_enable]', array(
		'selector'            => '#latest-products .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[recent_product_section_enable]',
    ) );
}

// recent_product title setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[recent_product_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_product_title'],
	'transport'			=> 'postMessage',

) );

$wp_customize->add_control( 'moun10_pro_theme_options[recent_product_title]', array(
	'label'           	=> esc_html__( 'Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_recent_product_section',
	'active_callback' 	=> 'moun10_pro_is_recent_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[recent_product_title]', array(
		'selector'            => '#latest-products .section-header h2.section-title',
		'settings'            => 'moun10_pro_theme_options[recent_product_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_recent_product_title_partial',
    ) );
}


// recent_product subtitle setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[recent_product_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_product_subtitle'],
	'transport'			=> 'postMessage',

) );

$wp_customize->add_control( 'moun10_pro_theme_options[recent_product_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_recent_product_section',
	'active_callback' 	=> 'moun10_pro_is_recent_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[recent_product_subtitle]', array(
		'selector'            => '#latest-products .section-header p.section-subtitle',
		'settings'            => 'moun10_pro_theme_options[recent_product_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_recent_product_subtitle_partial',
    ) );
}

// Product content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[recent_product_content_type]', array(
	'default'          	=> $options['recent_product_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recent_product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_recent_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_recent_product_section_enable',
	'choices'			=> moun10_pro_recent_product_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[recent_product_count]', array(
	'default'          	=> $options['recent_product_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_recent_product_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[recent_product_count]', array(
	'label'             => esc_html__( 'Number of Product', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_recent_product_section',
	'active_callback'   => 'moun10_pro_is_recent_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['recent_product_count']; $i++ ) :

	// recent_product posts drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[recent_product_content_recent_product_' . $i . ']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[recent_product_content_recent_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'moun10-pro' ), $i ),
		'section'           => 'moun10_pro_recent_product_section',
		'choices'			=> moun10_pro_product_choices(),
		'active_callback'	=> 'moun10_pro_is_recent_product_section_content_recent_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'moun10_pro_theme_options[recent_product_content_recent_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize,'moun10_pro_theme_options[recent_product_content_recent_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'moun10-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
	'section'           => 'moun10_pro_recent_product_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'moun10_pro_is_recent_product_section_content_recent_product_category_enable'
) ) );
