<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'moun10_pro_service_section', array(
	'title'             => esc_html__( 'Services','moun10-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_service_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[service_section_enable]', array(
		'selector'            => '#our-services .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[service_section_enable]',
    ) );
}

// Service section sub title control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[service_section_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=>'postMessage',
    'default'           => $options['service_section_sub_title'],
) );

$wp_customize->add_control('moun10_pro_theme_options[service_section_sub_title]', array(
    'label'             => esc_html__( 'Section Sub Title', 'moun10-pro' ),
    'section'           => 'moun10_pro_service_section',
    'type'              =>'text',
    'active_callback'	=> 'moun10_pro_is_service_section_enable',
));
$wp_customize->selective_refresh->add_partial(
    'moun10_pro_theme_options[service_section_sub_title]',
    array(
        'selector'            => '#our-services .section-subtitle',
        'render_callback'     => 'moun10_pro_service_section_partial_sub_title',
    )
);

// Service section title control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[service_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
    'transport'			=>'postMessage',
    'default'           => $options['service_section_title'],
    
) );

$wp_customize->add_control('moun10_pro_theme_options[service_section_title]', array(
    'label'             => esc_html__( 'Section Title', 'moun10-pro' ),
    'section'           => 'moun10_pro_service_section',
    'type'              =>'text',
    'active_callback'	=> 'moun10_pro_is_service_section_enable',
));
$wp_customize->selective_refresh->add_partial(
    'moun10_pro_theme_options[service_section_title]',
    array(
        'selector'            => '#our-services .section-title',
        'render_callback'     => 'moun10_pro_service_section_partial_title',
    )
);

// Service content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'moun10-pro' ),
		'post' 		=> esc_html__( 'Post', 'moun10-pro' ),
        'category' 	=> esc_html__( 'Category', 'moun10-pro' ),
	),
) );

// Services post number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[service_posts_count]', array(
	'default'          	=> $options['service_posts_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_service_posts_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[service_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_service_section',
	'active_callback'   => 'moun10_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
                'min'	=> 2,
                'max'	=> 6,
                'style' => 'width: 100px;'
            ),
) );

for($i = 1; $i <= $options['service_posts_count']; $i ++):
// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[service_content_page_'.$i.']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[service_content_page_'.$i.']', array(
		'label'             => sprintf(esc_html__( 'Select Page : %d', 'moun10-pro'), $i ),
		'section'           => 'moun10_pro_service_section',
		'choices'			=> moun10_pro_page_choices(),
		'active_callback'	=> 'moun10_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[service_content_post_'.$i.']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[service_content_post_'.$i.']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'moun10-pro'), $i ),
		'section'           => 'moun10_pro_service_section',
		'choices'			=> moun10_pro_post_choices(),
		'active_callback'	=> 'moun10_pro_is_service_section_content_post_enable',
	) ) );

    //Moun10_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('moun10_pro_theme_options[service_separator'. $i .']',array(
        'sanitize_callback'      => 'moun10_pro_sanitize_html',
    ));

    $wp_customize->add_control(new Moun10_Pro_Customize_Horizontal_Line($wp_customize,'moun10_pro_theme_options[service_separator'. $i .']',array(
        'active_callback'       => 'moun10_pro_is_service_section_separator_enable',
        'type'                  =>'hr',
        'section'               =>'moun10_pro_service_section',
    )));

endfor;

// service category drop down chooser control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[service_category]', array(
    'sanitize_callback' => 'moun10_pro_sanitize_single_category',
) );

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'moun10_pro_theme_options[service_category]', array(
    'label'             => esc_html__( 'Select Categories', 'moun10-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
    'type'           	=> 'dropdown-taxonomies',
    'section'           => 'moun10_pro_service_section',
    'active_callback'	=> 'moun10_pro_is_service_section_content_category_enable',
) ) );

// service content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[service_show_more]', array(
    'default'          	=> $options['service_show_more'],
    'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[service_show_more]', array(
    'label'             => esc_html__( 'Show More Option', 'moun10-pro' ),
    'section'           => 'moun10_pro_service_section',
    'type'				=> 'radio',
    'active_callback' 	=> 'moun10_pro_is_service_section_content_category_enable',
    'choices'			=> array(
        'ajax' 		=> esc_html__( 'Ajax Load', 'moun10-pro' ),
        'link' 		=> esc_html__( 'Category Link', 'moun10-pro' ),
    ),
) );
// Service Section button Text setting
$wp_customize->add_setting('moun10_pro_theme_options[service_post_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['service_post_btn_txt'],
    )
);

$wp_customize->add_control('moun10_pro_theme_options[service_post_btn_txt]',
    array(
        'section'			=> 'moun10_pro_service_section',
        'label'				=> esc_html__( 'Post Button Text:', 'moun10-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'moun10_pro_is_service_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[service_post_btn_txt]', array(
		'selector'            => '#our-services article .entry-container a.more-link',
		'settings'            => 'moun10_pro_theme_options[service_post_btn_txt]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_service_post_btn_txt_partial',
    ) );
}

// Service Section button Text setting
$wp_customize->add_setting('moun10_pro_theme_options[service_section_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['service_section_btn_txt'],
    )
);

$wp_customize->add_control('moun10_pro_theme_options[service_section_btn_txt]',
    array(
        'section'			=> 'moun10_pro_service_section',
        'label'				=> esc_html__( 'Button Text:', 'moun10-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'moun10_pro_is_service_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[service_section_btn_txt]', array(
		'selector'            => '#our-services div.read-more a.btn',
		'settings'            => 'moun10_pro_theme_options[service_section_btn_txt]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'moun10_pro_service_section_btn_txt_partial',
    ) );
}

$wp_customize->add_setting('moun10_pro_theme_options[service_section_btn_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
        'transport'			=> 'refresh',
        'default'           =>'#',
    )
);

$wp_customize->add_control('moun10_pro_theme_options[service_section_btn_url]',
    array(
        'section'			=> 'moun10_pro_service_section',
        'label'				=> esc_html__( 'Button URL:', 'moun10-pro' ),
        'type'          	=>'url',
        'active_callback' 	=> 'moun10_pro_is_service_section_btn_url_enable'
    )
);
