<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'moun10_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','moun10-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'moun10-pro' ),
	'panel'             => 'moun10_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_slider_section',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[slider_autoplay_enable]', array(
	'default'			=> 	$options['slider_autoplay_enable'],
	'sanitize_callback' => 'moun10_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Moun10_Pro_Switch_Control( $wp_customize, 'moun10_pro_theme_options[slider_autoplay_enable]', array(
	'label'             => esc_html__( 'Slider Autoplay Enable', 'moun10-pro' ),
	'section'           => 'moun10_pro_slider_section',
	'active_callback'   => 'moun10_pro_is_slider_section_enable',
	'on_off_label' 		=> moun10_pro_switch_options(),
) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[slider_autoplay_enable]', array(
		'selector'            => '#featured-slider .tooltiptext',
		'settings'            => 'moun10_pro_theme_options[slider_autoplay_enable]',
    ) );
}

// Slider number control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'moun10_pro_sanitize_number_range',
	'validate_callback' => 'moun10_pro_validate_slider_count',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Featured', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'moun10-pro' ),
	'section'           => 'moun10_pro_slider_section',
	'active_callback'   => 'moun10_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'moun10_pro_sanitize_select',
) );

$wp_customize->add_control( 'moun10_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'moun10-pro' ),
	'section'           => 'moun10_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'moun10_pro_is_slider_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'moun10-pro' ),
            'post' 		=> esc_html__( 'Post', 'moun10-pro' ),
            'category' 	=> esc_html__( 'Category', 'moun10-pro' ),
	),
) );


for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

		
	// slider section title control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[slider_section_sub_title_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['slider_section_sub_title'],
		'transport'			=>'refresh'
	) );

	$wp_customize->add_control('moun10_pro_theme_options[slider_section_sub_title_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Section Sub Title %d', 'moun10-pro' ), $i),
		'section'           => 'moun10_pro_slider_section',
		'type'              =>'text',
		'active_callback'	=> 'moun10_pro_is_slider_section_enable',
	));

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[slider_content_page_'. $i .']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[slider_content_page_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'moun10-pro'), $i ),
		'section'           => 'moun10_pro_slider_section',
		'choices'			=> moun10_pro_page_choices(),
		'active_callback'	=> 'moun10_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'moun10_pro_theme_options[slider_content_post_'. $i .']', array(
		'sanitize_callback' => 'moun10_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Moun10_Pro_Dropdown_Chooser( $wp_customize, 'moun10_pro_theme_options[slider_content_post_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'moun10-pro'), $i ),
		'section'           => 'moun10_pro_slider_section',
		'choices'			=> moun10_pro_post_choices(),
		'active_callback'	=> 'moun10_pro_is_slider_section_content_post_enable',
	) ) );

	//Moun10_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('moun10_pro_theme_options[slider_separator'. $i .']',array(
       'sanitize_callback'      => 'moun10_pro_sanitize_html',
    ));

    $wp_customize->add_control(new Moun10_Pro_Customize_Horizontal_Line($wp_customize,'moun10_pro_theme_options[slider_separator'. $i .']',array(
        'active_callback'       => 'moun10_pro_is_slider_section_separator_enable',
        'type'                  =>'hr',
        'section'               =>'moun10_pro_slider_section',
    )));

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'moun10_pro_theme_options[slider_category]', array(
	'sanitize_callback' => 'moun10_pro_sanitize_single_category',
) );

$wp_customize->add_control( new Moun10_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'moun10_pro_theme_options[slider_category]', array(
	'label'             => esc_html__( 'Select Categories', 'moun10-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'moun10-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'moun10_pro_slider_section',
	'active_callback'	=> 'moun10_pro_is_slider_section_content_category_enable',
) ) ); 

//slider_btn_txt
$wp_customize->add_setting('moun10_pro_theme_options[slider_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['slider_btn_txt'],
    )
);

$wp_customize->add_control('moun10_pro_theme_options[slider_btn_txt]',
    array(
        'section'			=> 'moun10_pro_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'moun10-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'moun10_pro_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[slider_btn_txt]', array(
		'selector'            => '#featured-slider article div.read-more a:nth-child(1)',
		'settings'            => 'moun10_pro_theme_options[slider_btn_txt]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
 		'render_callback'     => 'moun10_pro_slider_btn_txt_partial',
    ) );
}


//slider_btn_alt_txt
$wp_customize->add_setting('moun10_pro_theme_options[slider_btn_alt_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['slider_btn_alt_txt'],
        'transport'			=> 'postMessage',
    )
);

$wp_customize->add_control('moun10_pro_theme_options[slider_btn_alt_txt]',
    array(
        'section'			=> 'moun10_pro_slider_section',
        'label'				=> esc_html__( 'Button Alt Text:', 'moun10-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'moun10_pro_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'moun10_pro_theme_options[slider_btn_alt_txt]', array(
		'selector'            => '#featured-slider article div.read-more a:nth-child(2)',
		'settings'            => 'moun10_pro_theme_options[slider_btn_alt_txt]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
		'render_callback'     => 'moun10_pro_slider_btn_alt_txt_partial',
    ) );
}


// blog btn url setting and control
$wp_customize->add_setting( 'moun10_pro_theme_options[slider_btn_alt_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> $options['slider_btn_alt_url'],
) );

$wp_customize->add_control( 'moun10_pro_theme_options[slider_btn_alt_url]', array(
	'label'           	=> esc_html__( 'Button Alt URL', 'moun10-pro' ),
	'section'        	=> 'moun10_pro_slider_section',
	'active_callback' 	=> 'moun10_pro_is_slider_section_enable',
	'type'				=> 'url',
) );
