<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_blog_section() {
        $options = moun10_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'moun10_pro_section_status', true, 'blog_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design', 'seventh-design' ) ) ) {
             $blog_enable = false;
        }

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render blog section now.
        moun10_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input blog section details.
    */
    function moun10_pro_get_blog_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 6;
        
        
        $content = array();
        switch ( $blog_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $blog_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $blog_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $blog_count ),
                    'category__not_in'      => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['author']    = moun10_pro_author();
                $page_post['author_id'] = get_the_author_meta('ID');
                $page_post['excerpt']   = moun10_pro_trim_content( 15);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'moun10_pro_filter_blog_section_details', 'moun10_pro_get_blog_section_details' );


if ( ! function_exists( 'moun10_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_blog_section( $content_details = array() ) {
        $options                = moun10_pro_get_theme_options();
        $blog_content_type      = $options['blog_content_type'];
        if ( empty( $content_details ) ) {
            return;
        } ?>
       <?php ?>
       <div id="blog" class="col-2 page-section">
           <div class="wrapper">
              <?php if ( is_customize_preview()): ?>
                  <?php moun10_pro_section_tooltip( 'blog' ); ?>
              <?php endif ?>
               <div class="section-header">
                   <p class="section-subtitle"><?php echo esc_html($options['blog_section_sub_title'])?></p>
                   <h2 class="section-title"><?php echo esc_html($options['blog_title'])?></h2>
               </div><!-- .section-header -->
               <?php $chunk_content_details = array_chunk($content_details,7);
               foreach ($chunk_content_details as $contents):
               ?>
               <div class="blog-post-wrapper">
                   <div class="blog-wrapper">
                       <?php $post_content = array_slice($contents,0,2);
                       foreach ($post_content as $i=>$content):?>
                           <article class="hentry">
                               <div class="featured-image" style="background-image:url(<?php echo esc_url($content['image']);?>)">
                                   <a href="<?php echo esc_url($content['image']);?>" class="post-thumbnail-link"></a>
                               </div>
                               <div class="entry-container">
                                   <div class="entry-meta">
                                       <?php  moun10_pro_posted_on($content['id']); ?>
                                        <?php if ( 'page' !== $blog_content_type ) : ?>
                                           <span class="cat-links">
                                                <?php the_category( ', ', '', $content['id'] ); ?>
                                           </span><!-- .cat-links -->
                                        <?php endif; ?>
                                   </div><!-- .entry-meta -->

                                   <header class="entry-header">
                                       <h2 class="entry-title"><a href="<?php echo esc_url($content['url']);?>" tabindex="0"><?php echo esc_html($content['title']) ?></a></h2>
                                   </header>

                                   <div class="entry-content">
                                       <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                   </div>

                                   <div class="footer-meta">
                                        <a href="<?php echo esc_url(get_author_posts_url($content['author_id'])); ?>">
                                            <img src="<?php echo esc_url(get_avatar_url($content['author_id'], array('size'=> 32)));?>">
                                        </a>
                                       <?php echo $content['author']; ?>
                                       <p>
                                        <?php 
                                          $user_role = get_userdata($content['author_id']);

                                          echo esc_html( $user_role->roles[0] );
                                        ?>
                                            
                                        </p>
                                       
                                   </div><!-- .footer-meta -->
                               </div><!-- .entry-container -->
                           </article>
                       <?php endforeach; ?>
                   </div><!-- .blog-wrapper -->
                   <div class="blog-widget">
                       <h2 class="title"><?php echo esc_html($options['blog_right_sidebar_title']); ?></h2>
                       <ul>
                           <?php $post_content = array_slice($contents,2);
                           foreach ($post_content as $content) :?>
                               <li>
                                   <div class="featured-wrapper">
                                       <h3>
                                           <a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']);?></a>
                                       </h3>
                                       <div class="entry-meta">
                                            <?php moun10_pro_posted_on($content['id']); ?>
                                           <?php if ( 'page' !== $blog_content_type ) : ?>
                                               <span class="cat-links">
                                                <?php the_category( ', ', '', $content['id'] ); ?>
                                           </span><!-- .cat-links -->
                                           <?php endif; ?>
                                       </div><!-- .entry-meta -->
                                   </div>
                                   <?php if(!empty($content['image'])) :?>
                                    <a href="<?php echo esc_url($content['url']); ?>">
                                        <img src="<?php echo esc_url($content['image']);?>" alt="blog-03">
                                    </a>
                                   <?php endif; ?>
                               </li>
                           <?php endforeach;?>
                       </ul>
                   </div><!-- .blog-widget -->
                   <?php endforeach; ?>
               </div><!-- .blog-post-wrapper -->
           </div><!-- .wrapper -->
       </div><!-- .blog -->
    <?php }
endif;  ?>
