<?php
/**
 * Offers section
 *
 * This is the template for the content of Offers section
 *
 * @offer Theme Palace
 * @suboffer Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_offer_section' ) ) :
    /**
    * Add Offers section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_offer_section() {
        $options = moun10_pro_get_theme_options();
        
        // Check if Offers is enabled on frontpage
        $offer_enable = apply_filters( 'moun10_pro_section_status', true, 'offer_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design' ) ) ) {
            $offer_enable = false;
        }

        if ( true !== $offer_enable ) {
            return false;
        }
        // Get Offers section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_offer_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Offers section now.
        moun10_pro_render_offer_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_offer_section_details' ) ) :
    /**
    * Offers section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input Offers section details.
    */
    function moun10_pro_get_offer_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        $offer_count  = $options['offer_count']; // Pakage Content Type
        $offer_content_type  = $options['offer_content_type']; // Offers Post Count

        $content = array();
        $args = array();
        switch ( $offer_content_type ) {
            case 'page':
				$page_ids = array();

				for ( $i = 1; $i <= $offer_count; $i++ ) {
					if ( ! empty( $options['offer_content_page_' . $i] ) )
						$page_ids[] = $options['offer_content_page_' . $i];
				}
				
				$args = array(
					'post_type'         => 'page',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $offer_count ),
					'orderby'           => 'post__in',
					);                    
			break;

			case 'post':
				$post_ids = array();

				for ( $i = 1; $i <= $offer_count; $i++ ) {
					if ( ! empty( $options['offer_content_post_' . $i] ) )
						$post_ids[] = $options['offer_content_post_' . $i];
				}
				$args = array(
					'post_type'             => 'post',
					'post__in'              => ( array ) $post_ids,
					'posts_per_page'        => absint( $offer_count ),
					'orderby'               => 'post__in',
					'ignore_sticky_posts'   => true,
					);                    
			break;
        	
            case 'category':
                $cat_ids = ! empty( $options['offer_content_category'] ) ? $options['offer_content_category'] : '';

                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint($offer_count),
                    'cat'                   =>  absint($cat_ids),
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $offer_count; $i++ ) {
                    if ( ! empty( $options['offer_content_trip_' . $i] ) )
                        $page_ids[] = $options['offer_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $offer_count ),
                    'orderby'           => 'post__in',
                    );   

            break;

            case 'trip-types': // trip-types
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = ! empty( $options['offer_content_trip_types'] ) ? $options['offer_content_trip_types'] : '';

                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  =>absint($offer_count),
                    );
                $content['taxonomy'] = 'itinerary_types';

            break;

            case 'destination':  //Destination
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                $cat_ids = ! empty( $options['offer_content_destination'] ) ? $options['offer_content_destination'] : '';
                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  => absint($offer_count),
                    ); 
                $content['taxonomy'] = 'travel_locations';

            break;

            case 'activity': //Activity
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_ids = ! empty( $options['offer_content_activity'] ) ? $options['offer_content_activity'] :'';

                if ( empty( $cat_ids ) )
                    return;

                $args = array(
                    'post_type' => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_ids,
                        ),
                    ),
                    'posts_per_page'  =>absint($offer_count),
                    ); 
                $content['taxonomy'] = 'activity';

            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
		$content['details'] = array();
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = moun10_pro_trim_content(30);
                $page_post['url']       = get_the_permalink();
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) :  get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;    

// Offers section content details.
add_filter( 'moun10_pro_filter_offer_section_details', 'moun10_pro_get_offer_section_details' );


if ( ! function_exists( 'moun10_pro_render_offer_section' ) ) :
  /**
   * Start Offers section
   *
   * @return string Offers content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_offer_section( $content_details = array() ) {
        $options                = moun10_pro_get_theme_options();
        $offer_content_type   = $options['offer_content_type'];
        $offer_btn_title      = $options['offer_btn_title'];
        if ( empty( $content_details ) ) {
           return;
        } ?>

        <div id="special-offers" class="relative page-section">
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                      <?php moun10_pro_section_tooltip( 'special-offers' ); ?>
                  <?php endif ?>
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html( $options['offer_sub_title']); ?></p>
                    <h2 class="section-title"><?php echo esc_html( $options['offer_title']); ?></h2>
                </div><!-- .section-header -->   

                <div class="section-content col-4 clear">
                <?php  foreach ($content_details['details'] as $content): ?>

                    <article>
                        <div class="destination-item-wrapper">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image']); ?>">

                            <?php if(class_exists('WP_Travel') && ! in_array( $offer_content_type, array( 'category', 'page', 'post' ) ) ) :
                                $trip_price     = WP_Travel_Helpers_Pricings::get_price( array( 'trip_id'=> $content['id'] ) ); ?>
                                <div class="price-wrapper">
                                    <span class="trip-price">                       
                                        <span class="current-price"><?php echo wptravel_get_formated_price_currency( $trip_price ); ?></span>
                                        <?php if ( wptravel_tab_show_in_menu( 'reviews' ) ) :
											$average_rating = wptravel_get_average_rating( $content['id'] ); ?>
											<div class="wp-travel-average-review"
												title="<?php printf( esc_attr__( 'Rated %s out of 5', 'moun10-pro' ), $average_rating ); ?>">
												<span style="width:<?php echo esc_attr( ( $average_rating / 5 ) * 100 ); ?>%">
													<strong itemprop="ratingValue"
														class="rating"><?php echo esc_html( $average_rating ); ?></strong>
													<?php printf( esc_html__( 'out of %1$s5%2$s', 'moun10-pro' ), '<span itemprop="bestRating">', '</span>' ); ?>
												</span>
											</div>
										<?php endif; ?>
                                    </span><!-- .trip-price -->
                                </div><!-- .price-wrapper -->
                            <?php endif;?>
                            
                            </div><!-- .featured-image -->
                            <div class="entry-container clear">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    <?php if(class_exists('WP_Travel') && ! in_array( $offer_content_type, array( 'category', 'page', 'post' ) ) ) echo '<span>'.wptravel_get_trip_duration( $content['id'] ).'</span>' ;?>
                                </header>   
                            </div><!-- .entry-container -->
                        </div><!-- .destination-item-wrapper -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->

                <?php if(!empty($offer_btn_title) && !empty($options['offer_btn_url'])): ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url($options['offer_btn_url']); ?>" class="btn"><?php echo esc_html($offer_btn_title); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div>
        
    <?php }
endif;